Welcome to Logbook
==================

.. image:: https://secure.travis-ci.org/mitsuhiko/logbook.png
        :target: https://travis-ci.org/mitsuhiko/logbook

.. image:: https://pypip.in/d/Logbook/badge.png
        :target: https://crate.io/packages/Logbook

.. image:: https://pypip.in/v/Logbook/badge.png
        :target: https://crate.io/packages/Logbook

Logbook is a nice logging replacement.

It should be easy to setup, use and configure and support web applications :)

For more information look at http://pythonhosted.org/Logbook
